%global pkgname larch

Name:           python-%{pkgname}
Version:        1.20151025
Release:        7%{?dist}
Summary:        Python B-tree library

License:        GPLv3+
URL:            http://liw.fi/%{pkgname}/
Source0:        http://code.liw.fi/debian/pool/main/p/%{name}/%{name}_%{version}.orig.tar.xz
# sent to upstream via mailing list
Patch0:         %{name}-1.20151025-cov40.patch

BuildArch:      noarch
# build-time only
BuildRequires:  python2-devel
BuildRequires:  cmdtest
BuildRequires:  python-coverage-test-runner
BuildRequires:  python-sphinx
# build- and run-time
BuildRequires:  python-cliapp
BuildRequires:  python-tracing
BuildRequires:  python-ttystatus
BuildRequires:  python2-markdown

%global _description\
This is an implementation of particular kind of B-tree, based on\
research by Ohad Rodeh. See "B-trees, Shadowing, and Clones" (copied\
here with permission of author) for details on the data\
structure. This is the same data structure that btrfs uses. Note that\
my implementation is independent from the btrfs one, and might differ\
from what the paper describes.\
\
The distinctive feature of this B-tree is that a node is never\
modified (sort-of). Instead, all updates are done by\
copy-on-write. Among other things, this makes it easy to clone a tree,\
and modify only the clone, while other processes access the original\
tree. This is utterly wonderful for my backup application, and that's\
the reason I wrote larch in the first place.\
\
I have tried to keep the implementation generic and flexible, so that\
you may use it in a variety of situations. For example, the tree\
itself does not decide where its nodes are stored: you provide a class\
that does that for it. I have two implementations of the NodeStore\
class, one for in-memory and one for on-disk storage.\
\
The tree attempts to guarantee this: all modifications you make will\
be safely stored in the node store when the larch.Forest.commit method\
is called. After that, unless you actually modify the committed tree\
yourself, it will be safe from further modifications. (You need to\
take care to create a new tree for further modifications, though.)\


%description %_description

%package -n python2-%{pkgname}
Summary: %summary
Requires:       python-cliapp
Requires:       python-tracing
Requires:       python-ttystatus
%{?python_provide:%python_provide python2-%{pkgname}}

%description -n python2-%{pkgname} %_description

%package        doc
Summary:        Documentation for %{pkgname}
Requires:       python2-%{pkgname} = %{version}-%{release}

%description    doc
This package contains the documentation for %{pkgname}, a Python
framework for Unix command line programs.


%prep
%autosetup -p1


%build
%{__python} setup.py build
# Build documentation
make


%install
%{__python} setup.py install -O1 --skip-build --root %{buildroot}
# manpage not installed automatically yet
mkdir -p %{buildroot}%{_mandir}/man1
cp -p fsck-larch.1 %{buildroot}%{_mandir}/man1/


%check
# CoverageTestRunner trips up on build directory;
# since we've already done the install phase, remove it first
rm -rf build
make check


%files -n python2-%{pkgname}
%doc COPYING NEWS README
%{_mandir}/man1/fsck-larch.1*
%{_bindir}/fsck-larch
%{python_sitelib}/*

%files doc
%doc doc/_build/html/*


%changelog
* Tue Aug 29 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.20151025-7
- Update name in internal Requires on -doc subpackage

* Mon Aug 28 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.20151025-6
- Add missing pyton2-devel dep

* Thu Aug 10 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.20151025-5
- Python 2 binary package renamed to python2-larch
  See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.20151025-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.20151025-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.20151025-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Mon Feb 15 2016 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.20151025-1
- Update to 1.20151025

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.20131130-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.20131130-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Nov 27 2014 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.20131130-1
- Update to 1.20131130

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.20130808-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Sep 27 2013 Michel Salim <salimma@fedoraproject.org> - 1.20130808-1
- Update to 1.20130808

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.20130316-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Mar 17 2013 Michel Salim <salimma@fedoraproject.org> - 1.20130316-1
- Update to 1.20130316

* Mon Feb 25 2013 Michel Salim <salimma@fedoraproject.org> - 1.20121216-1
- Update to 1.20121216

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.20121006-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Oct  8 2012 Michel Salim <salimma@fedoraproject.org> - 1.20121006-1
- Update to 1.20121006

* Sun Sep 16 2012 Michel Salim <salimma@fedoraproject.org> - 1.20120527-3
- Switch source URL to Debian servers

* Tue Jun 19 2012 Michel Salim <salimma@fedoraproject.org> - 1.20120527-2
- Remove redundant %%{python_sitelib} declaration
- Fix %%check when using latest version of CoverageTestRunner

* Sun Jun  3 2012 Michel Salim <salimma@fedoraproject.org> - 1.20120527-1
- Initial package
